=== modified file 'utilities/local-latency'
--- utilities/local-latency	2011-08-04 15:24:09 +0000
+++ utilities/local-latency	2011-08-04 15:50:52 +0000
@@ -2,37 +2,20 @@
 
 __metaclass__ = type
 
-from optparse import OptionParser
 import sys
 import subprocess
 
-
-class UserError(Exception):
-    pass
+from script_commands import (
+    Command,
+    OptionParser,
+    UserError,
+    )
 
 
 def tc(command):
      subprocess.call('sudo tc ' + command, shell=True)
 
 
-class Command:
-
-    UNSPECIFIED = object()
-
-    @classmethod
-    def get_specified_values(cls, parser, cmd_args):
-        options, args = parser.parse_args(cmd_args)
-        kwargs = dict(
-            item for item in options.__dict__.items()
-            if item[1] is not cls.UNSPECIFIED)
-        return args, kwargs
-
-    @classmethod
-    def run_from_args(cls, cmd_args):
-        args, kwargs = cls.get_specified_values(cls.get_parser(), cmd_args)
-        cls.run(*args, **kwargs)
-
-
 class StartCommand(Command):
 
     @classmethod
@@ -40,7 +23,6 @@
         parser = OptionParser()
         parser.add_option(
             '-d', '--delay', dest='delay', type='int',
-            default=cls.UNSPECIFIED,
             help='Length of delay in miliseconds (each way).')
         return parser
 
@@ -54,6 +36,9 @@
            ' sport %d 0xffff flowid 1:3' % port)
 
 
+Command.commands['start'] = StartCommand
+
+
 class StopCommand(Command):
 
     @staticmethod
@@ -66,24 +51,12 @@
         tc('qdisc del dev lo root')
 
 
-def main(argv):
-    commands = {
-        'start': StartCommand,
-        'stop': StopCommand,
-    }
-    if len(argv) < 1:
-        raise UserError('Must supply a command: %s.' %
-                        ', '.join(commands.keys()))
-    try:
-        command = commands[argv[0]]
-    except KeyError:
-        raise UserError('%s invalid.  Valid commands: %s.' %
-                        (argv[0], ', '.join(commands.keys())))
-    command.run_from_args(argv[1:])
+Command.commands['stop'] = StopCommand
+
 
 
 if __name__ == "__main__":
     try:
-        main(sys.argv[1:])
-    except UserError, e:
+        Command.run_subcommand(sys.argv[1:])
+    except UserError as e:
         sys.stderr.write(str(e)+'\n')

=== added file 'utilities/script_commands.py'
--- utilities/script_commands.py	1970-01-01 00:00:00 +0000
+++ utilities/script_commands.py	2011-08-04 15:50:52 +0000
@@ -0,0 +1,56 @@
+import optparse
+
+
+class UserError(Exception):
+    pass
+
+
+class OptionParser(optparse.OptionParser):
+
+    UNSPECIFIED = object()
+
+    def add_option(self, *args, **kwargs):
+        """Add an option, with the default that it not be included."""
+        kwargs['default'] = kwargs.get('default', self.UNSPECIFIED)
+        optparse.OptionParser.add_option(self, *args, **kwargs)
+
+    def parse_args_dict(self, cmd_args):
+        """Return a dict of specified options.
+
+        Unspecified options with no explicit default are not included in the
+        dict."""
+        options, args = self.parse_args(cmd_args)
+        option_dict = dict(
+            item for item in options.__dict__.items()
+            if item[1] is not self.UNSPECIFIED)
+        return args, option_dict
+
+
+class Command:
+    """Base class for subcommands."""
+
+    commands = {}
+
+    @classmethod
+    def parse_args(cls, args):
+        if len(args) != 0:
+            raise UserError('Too many arguments.')
+        return {}
+
+    @classmethod
+    def run_from_args(cls, cmd_args):
+        args, kwargs = cls.get_parser().parse_args_dict(cmd_args)
+        kwargs.update(cls.parse_args(args))
+        cls.run(**kwargs)
+
+    @classmethod
+    def run_subcommand(cls, argv):
+        if len(argv) < 1:
+            raise UserError('Must supply a command: %s.' %
+                            ', '.join(cls.commands.keys()))
+        try:
+            command = cls.commands[argv[0]]
+        except KeyError:
+            raise UserError('%s invalid.  Valid commands: %s.' %
+                            (argv[0], ', '.join(cls.commands.keys())))
+        command.run_from_args(argv[1:])

